# acl/security/dependencies.py
from fastapi import Header
from sqlalchemy.orm import Session
from db import SessionLocal  # app using the library must supply its own db.py


def get_db():
    db = SessionLocal()
    try:
        yield db
    finally:
        db.close()


async def get_current_user_id(x_user_id: str = Header(...)) -> str:
    """In real implementation decode JWT; here header carries UUID."""
    return x_user_id


async def get_current_account_id(x_account_id: str = Header(...)) -> str:
    return x_account_id



# acl/security/__init__.py
from .dependencies import get_db, get_current_user_id, get_current_account_id
from .permission_required import permission_required
from .permission_service import permission_service
from .permission_handler import register_permission_handler, PermissionHandler


__all__ = [
  "get_db",
  "get_current_user_id",
  "get_current_account_id",
  "permission_required",
  "permission_service",
  "register_permission_handler",
  "PermissionHandler"
]